import pritunl

print '##############################################################'
print '#                                                            #'
print '#                      /$$   /$$                         /$$ #'
print '#                     |__/  | $$                        | $$ #'
print '#   /$$$$$$   /$$$$$$  /$$ /$$$$$$   /$$   /$$ /$$$$$$$ | $$ #'
print '#  /$$__  $$ /$$__  $$| $$|_  $$_/  | $$  | $$| $$__  $$| $$ #'
print '# | $$  \ $$| $$  \__/| $$  | $$    | $$  | $$| $$  \ $$| $$ #'
print '# | $$  | $$| $$      | $$  | $$ /$$| $$  | $$| $$  | $$| $$ #'
print '# | $$$$$$$/| $$      | $$  |  $$$$/|  $$$$$$/| $$  | $$| $$ #'
print '# | $$____/ |__/      |__/   \___/   \______/ |__/  |__/|__/ #'
print '# | $$                                                       #'
print '# | $$                                                       #'
print '# |__/                                                       #'
print '#                                                            #'
print '##############################################################'

pritunl.app_server.conf_path = './tools/development_pritunl.conf'
pritunl.app_server.run_server()
